@@ -155,7 +155,7 @@ public:
 //---------------------------------------------------------------------------------------
 
 NotifyByPopup::NotifyByPopup(QObject *parent) 
-  : KNotifyPlugin(parent),
+  : KNotificationPlugin(parent),
     d(new NotifyByPopupPrivate(this))
 {
     d->animationTimer = 0;
@@ -256,6 +256,11 @@ void NotifyByPopup::notify(KNotification *notification, KNotifyConfig *notifyCon
         QString appCaption, iconName;
         d->getAppCaptionAndIconName(notifyConfig, &appCaption, &iconName);
 
+        //did the user override the icon name?
+        if (!notification->iconName().isEmpty()) {
+            iconName = notification->iconName();
+        }
+
         KIconLoader iconLoader(iconName);
         QPixmap appIcon = iconLoader.loadIcon(iconName, KIconLoader::Small);
 
@@ -309,7 +314,7 @@ void NotifyByPopup::onPassivePopupDestroyed()
 void NotifyByPopup::timerEvent(QTimerEvent *event)
 {
     if (event->timerId() != d->animationTimer) {
-        return KNotifyPlugin::timerEvent(event);
+        return KNotificationPlugin::timerEvent(event);
     }
 
     bool cont = false;
@@ -588,6 +593,11 @@ bool NotifyByPopupPrivate::sendNotificationToGalagoServer(KNotification *notific
     QString iconName;
     getAppCaptionAndIconName(notifyConfig_nocheck, &appCaption, &iconName);
 
+    //did the user override the icon name?
+    if (!notification->iconName().isEmpty()) {
+        iconName = notification->iconName();
+    }
+
     // FIXME: rename this to something better reflecting what this is doing...maybe
     ensurePopupCompatibility(notification);
 
